@@ -3,6 +3,7 @@
 from resources.models.database import SqlConnection
 from resources.delete_old_data import Cleaner
 
+
 class BenchmarkDBResource(object):
 
     def __init__(self, db_name="performance_test"):
@@ -259,6 +260,28 @@ class BenchmarkDBResource(object):
             test_results.append(test)
         return test_results
 
+    def _get_dut_information(self, dut_index):
+        dut = dict()
+        if dut_index is not None and dut_index > 0:
+            command = f"SELECT * FROM dut WHERE `index`={dut_index}"
+            results = self.sql.execute_sql_command(command)
+            if results:
+                dut = {
+                    "vendor": results[0][3],
+                    "fw_version": results[0][1],
+                    "commit": results[0][4],
+                    "ise/sed": results[0][9],
+                    "security_status": results[0][8],
+                    "sn": results[0][1],
+                    "cap": results[0][5],
+                    "bb": results[0][11],
+                    "max_ec": results[0][13],
+                    "avg_ec": results[0][14],
+                    "min_ec": results[0][15],
+                    "pn": results[0][6]
+                }
+        return dut
+
     def get_test_detail_information(self, test_key):
         """
         get test detail information by test key
@@ -279,7 +302,8 @@ class BenchmarkDBResource(object):
                 "duration": self._get_duration(item[11], item[12]),
                 "environment": self._get_env_by_index(item[0]),
                 "summary_report": self._get_summary_report_by_index(item[0]),
-                "configuration": self._get_test_config(item[0])}
+                "configuration": self._get_test_config(item[0]),
+                "dut": self._get_dut_information(item[16])}
             test_steps.append(step)
         return test_steps
 
